Index: trunk/psLib/src/dataIO/psLookupTable.h
===================================================================
--- trunk/psLib/src/dataIO/psLookupTable.h	(revision 4366)
+++ trunk/psLib/src/dataIO/psLookupTable.h	(revision 4457)
@@ -7,6 +7,6 @@
 *  @author Ross Harman, MHPCC
 *
-*  @version $Revision: 1.9 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-06-23 03:19:29 $
+*  @version $Revision: 1.10 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-07-06 03:04:35 $
 *
 *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -33,6 +33,6 @@
     psVector *index;                   ///< Vector of independent index values
     psArray *values;                   ///< Array of dependent table values corresponding to index values
-    psF64 validFrom;                   ///< Lower bound for rable read
-    psF64 validTo;                     ///< Upper bound for table read
+    const double validFrom;            ///< Lower bound for rable read
+    const double validTo;              ///< Upper bound for table read
 }
 psLookupTable;
@@ -100,5 +100,5 @@
  *  Reads a lookup table and fills corresponding psLookupTable struct.
  *
  *  @return psS32     Number of valid lines read
  */
 long psLookupTableRead(
@@ -111,10 +111,10 @@
  *  conditions.
  *
- *  @return psLookupTable*     New psLookupTable struct
+ *  @return double     Interpolation value at index
  */
-psF64 psLookupTableInterpolate(
-    const psLookupTable *table,     ///< Table with data
-    psF64 index,                    ///< Value to be interpolated
-    psS32 column                    ///< Column in table to be interpolated
+double psLookupTableInterpolate(
+    const psLookupTable *table,        ///< Table with data
+    double index,                      ///< Value to be interpolated
+    long column                        ///< Column in table to be interpolated
 );
 
@@ -124,9 +124,9 @@
  *  conditions.
  *
- *  @return psLookupTable*     New psLookupTable struct
+ *  @return psVector*     Interpolation values calculated at index
  */
 psVector* psLookupTableInterpolateAll(
-    psLookupTable *table,           ///< Table with data
-    psF64 index                     ///< Value to be interpolated
+    const psLookupTable *table,        ///< Table with data
+    double index                       ///< Value to be interpolated
 );
 
@@ -100,5 +100,5 @@
  *  Reads a lookup table and fills corresponding psLookupTable struct.
  *
- *  @return psS32     Number of valid lines read
+ *  @return long:     Number of valid lines read
  */
 long psLookupTableRead(
